@@ -7,14 +7,19 @@ my $P = Tk::SlideShow->init(1024,768) or die;
 
 $P->save;
 
-my ($mw,$c,$h,$w) = ($P->mw, $P->can, $P->h, $P->w);
+my ($mw,$c,$h,$w) = ($P->mw, $P->canvas, $P->h, $P->w);
 my $d;
 
-sub title {$P->Text('title',shift,-font,$P->f3);}
+sub title {
+  $P->Image('ti',"Xcamel.gif");
+  $P->Text('title',shift,-font,$P->f3);
+}
 
 sub items {
   my ($id,$items,@options) = @_;
   for (split (/\n/,$items)) {
+    s/^\s*//;
+    s/\s*$//;
     $P->Text($id,$_,@options);
 	    $id++;
   }
@@ -30,43 +35,45 @@ $d = $P->add('summary',sub {
 	  for (0..2) {$P->a_top("a$_"); $P->a_bottom("b$_");}
 });
 
-$d->latex("
-\\paragraph{What's Tk::SlideShow ?}
+$d->html("
+<h1>What's Tk::SlideShow ? </h1>
 
 Tk::SlideShow is a module that will help perl to be a very
 	  powerfull tool for building presentation
 
-\\paragraph{Why using perl for that purpose}
+<p>
+
+<h2>Why using perl for that purpose </h2>
 
 There are good reason for using Tk::SlideShow :
 
-\\begin{enumerate}
+<ul>
 
-\\item Filling the lack of free tools for building presentation like
+<li> Filling the lack of free tools for building presentation like
 what you can do with PowerPoint.
 
-\\item Simply building simple slide,
+<li> Simply building simple slide,
 
-\\item Being able to build very elaborated slides, up to real GUI
+<li> Being able to build very elaborated slides, up to real GUI
 interface,
 
-\\item Structured your presentations using a structured language,
+<li> Structured your presentations using a structured language,
 
-\\item Or even a OO presentation using a OO language,
+<li> Or even a OO presentation using a OO language,
 
-\\end{enumerate}
+</ul>
 
 When using a tool like PowerPoint, you have 2 types of interaction :
 
-\\begin{enumerate}
+<ul>
 
-\\item description of what you want to see thru menus, dialog box and
+<li> description of what you want to see thru menus, dialog box and
 templates and typing text. This is roughly programming with a mouse ;
 
-\\item interactive and approximative placement of what you want to see
+<li> interactive and approximative placement of what you want to see
 : this is Art !
 
-\\end{enumerate}
+</ul>
 
 Tk::SlideShow will try to target the former with perl script rather than a
 two buttons mouse, and will probably be much more powerful. Tk::SlideShow
@@ -74,10 +81,11 @@ will try to target the later with Tk interaction. It will probably not
 reach the Artistic Quality of a PowerPoint like tools. But one never
 know !
 
-\\paragraph{How to use it ?}
+<h2>How to use it ? </h2>
 
 Well, mostly by examples, because perl folks don't like having to
-learn another theory when explaining there's");
+learn another theory when explaining their's
+");
 
 
 
@@ -103,22 +111,22 @@ $d = $P->add('prerequisite',sub {
 		  -font => $P->ff2
 		 );
 	  items('a0',"You have to know Perl and Tk !
-Tell what your screen size
-Ask for your Art to be saved",
+                      Tell what your screen size is.
+                      Ask for your Art to be saved.",
 		-font => $P->f2,-fill, 'red');
 	  $P->load;
 	  for (0..2) {$P->a_bottom("a$_")}
 	});
 
-$d->latex("
-\\paragraph{You have to know Perl/Tk}
+$d->html("
+<h1>You have to know Perl/Tk</h1>
 
 Yes, there is no power in Tk::SlideShow. The power is in Perl and in Tk. You
 will reuse all what you have learn. That's the trick : Tkpp only takes
 advantage of what you already know. Leave now this reading,
 un(til\|less) you know a little bit perl/Tk.
 
-\\paragraph{Tell what your screen size is}
+<h1>Tell what your screen size is</h1>
 
 Sometimes, you are developping your application on 21~inch screen with
 a resolution of \$1600 \\times 1280\$ and the projector will only be
@@ -129,7 +137,7 @@ root.
 To short the examples given there, I assume that these lines will be
 at the beginning of each example.
 
-\\paragraph{Ask for your Art to be saved}
+<h1>Ask for your Art to be saved </h1>
 
 When building your presentation, you will be able to place visual
 object with the mouse. This has to be saved so that when restarting
@@ -161,40 +169,44 @@ Load the positions",
 	  for (0..4) {$P->a_bottom("a$_")}
 	});
 
-$d->latex("
-\\paragraph{Your first slide}
+$d->html("
+<h2>Your first slide</h2>
 OK, now, you are dying to know how to build a first
 slide. That's simple, if what you want is simple.
 
-\\paragraph{Add a slide}
+<h2>paragraph{Add a slide</h2>
 A presentation is a pile of slides. You just have to add
 a slide to the presentation by using the method \\texttt{\\bf add}
 
-\\paragraph{Give it a name}
+<h2>Give it a name</h2>
 Because your slide is probably something you will reference in the
 future, your had better to give it a name. If not, Tk::SlideShow will find one
 for you. In this example, this is {\\it first-slide}. This name will also
 be used to store positions of the objets you will place interactively
 on the screen.
 
-\\paragraph{Give the sub}
+<h2>Give the sub </h2>
 Well, a slide for Tk::SlideShow is rougly a sub reference. This sub will be call 
 when Tk::SlideShow has to show the slide. That's all.
 
-\\paragraph{Describe the text} Here, you see a new method,
+<h2>Describe the text</h2>
+
+Here, you see a new method.
 \\texttt{\\bf Text}, that is used to place a text on the screen. You do not
 know where the text will be place. This will be done with your mouse,
 dragging the text with button one. When the artisitic position are
 good for you, then just press key \\texttt{\\bf s} to save the position 
 in a file.
 
-\\paragraph{Load the positions} Then, you can load the positions of your
-texts, you have previously saved.
+<h2>Load the positions</h2>
+
+ Then, you can load the positions of your texts, you have previously
+saved.
 
 ");
 
-if (grep (/-latex/,@ARGV)) {
-  $P->latex("doc.tex");
+if (grep (/-html/,@ARGV)) {
+  $P->html("doc");
   exit 0;
 }
 
